==> pegasus-merchandise-api-3.7.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProductdetailMatchVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class OpProductdetailMatchVO implements Serializable {
    private Integer id;
    private Integer status;
    private String statusText;

    private Integer createId;
    private String createName;
    private Date createTime;
    private Date updateTime;


    private List<OpProductdetailMatchDetailVO> mainProductVOList;
    private List<OpProductdetailMatchDetailVO> matchProductVOList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusText() {
        return statusText;
    }

    public void setStatusText(String statusText) {
        this.statusText = statusText;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }


    public List<OpProductdetailMatchDetailVO> getMainProductVOList() {
        return mainProductVOList;
    }

    public void setMainProductVOList(List<OpProductdetailMatchDetailVO> mainProductVOList) {
        this.mainProductVOList = mainProductVOList;
    }

    public List<OpProductdetailMatchDetailVO> getMatchProductVOList() {
        return matchProductVOList;
    }

    public void setMatchProductVOList(List<OpProductdetailMatchDetailVO> matchProductVOList) {
        this.matchProductVOList = matchProductVOList;
    }
}

==> pegasus-merchandise-api-3.8.8-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProductdetailMatchVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class OpProductdetailMatchVO implements Serializable {
    private Integer id;
    private Integer status;
    private String statusText;

    private String name;

    private Integer createId;
    private String createName;
    private Date createTime;
    private Date updateTime;


    private List<OpProductdetailMatchDetailVO> mainProductVOList;
    private List<OpProductdetailMatchDetailVO> matchProductVOList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getStatusText() {
        return statusText;
    }

    public void setStatusText(String statusText) {
        this.statusText = statusText;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }


    public List<OpProductdetailMatchDetailVO> getMainProductVOList() {
        return mainProductVOList;
    }

    public void setMainProductVOList(List<OpProductdetailMatchDetailVO> mainProductVOList) {
        this.mainProductVOList = mainProductVOList;
    }

    public List<OpProductdetailMatchDetailVO> getMatchProductVOList() {
        return matchProductVOList;
    }

    public void setMatchProductVOList(List<OpProductdetailMatchDetailVO> matchProductVOList) {
        this.matchProductVOList = matchProductVOList;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}
